==> wow_views-0.0.46.tar.gz: lib/common/theme/theme_data.dart <==
import 'package:flutter/material.dart';
import 'package:wow_views/common/color.dart';
import 'package:wow_views/common/text_style.dart';
import 'package:wow_views/common/theme/app_bar_theme.dart';
import 'package:wow_views/common/theme/icon_theme.dart';
import 'package:wow_views/common/theme/input_decoration_theme.dart';
import 'package:wow_views/common/theme/progress_indicator_theme.dart';
import 'package:wow_views/common/theme/text_selection_theme.dart';
import 'text_theme.dart';

ThemeData bds8xThemeData({
  required String fontFamily,
}) {
  WowTextStyle.initTextTheme(bds8xTextTheme);
  return ThemeData(
    appBarTheme: bds8xAppBarTheme,
    fontFamily: fontFamily,
    textTheme: bds8xTextTheme,
    textSelectionTheme: bds8xTextSeletionTheme,
    backgroundColor: Bds8xColor.white,
    primaryColor: Bds8xColor.blue367E,
    indicatorColor: Bds8xColor.blue367E,
    scaffoldBackgroundColor: Bds8xColor.white,
    inputDecorationTheme: bds8xInputDecorationTheme,
    iconTheme: bds8xIconTheme,
    progressIndicatorTheme: bds8xProgressIndicatorTheme,
  );
}

ThemeData tbtThemeData({
  required String fontFamily,
}) {
  WowTextStyle.initTextTheme(tbtTextTheme);
  return ThemeData(
    fontFamily: fontFamily,
    appBarTheme: tbtAppBarTheme,
    textTheme: tbtTextTheme,
    textSelectionTheme: tbtTextSeletionTheme,
    backgroundColor: TBTColor.whiteF1F2,
    primaryColor: TBTColor.pink4667,
    indicatorColor: TBTColor.pink4667,
    scaffoldBackgroundColor: TBTColor.whiteF1F2,
    inputDecorationTheme: tbtInputDecorationTheme,
    iconTheme: tbtIconTheme,
    progressIndicatorTheme: tbtProgressIndicatorTheme,
  );
}

==> wow_views-0.0.48.tar.gz: lib/common/theme/theme_data.dart <==
import 'package:flutter/material.dart';
import 'package:wow_views/common/color.dart';
import 'package:wow_views/common/text_style.dart';
import 'package:wow_views/common/theme/app_bar_theme.dart';
import 'package:wow_views/common/theme/icon_theme.dart';
import 'package:wow_views/common/theme/input_decoration_theme.dart';
import 'package:wow_views/common/theme/progress_indicator_theme.dart';
import 'package:wow_views/common/theme/text_selection_theme.dart';
import 'text_theme.dart';

ThemeData bds8xThemeData({
  required String fontFamily,
}) {
  WowTextStyle.initTextTheme(bds8xTextTheme);
  return ThemeData(
    appBarTheme: bds8xAppBarTheme,
    fontFamily: fontFamily,
    textTheme: bds8xTextTheme,
    textSelectionTheme: bds8xTextSeletionTheme,
    backgroundColor: Bds8xColor.white,
    primaryColor: Bds8xColor.blue367E,
    indicatorColor: Bds8xColor.blue367E,
    scaffoldBackgroundColor: Bds8xColor.white,
    inputDecorationTheme: bds8xInputDecorationTheme,
    iconTheme: bds8xIconTheme,
    progressIndicatorTheme: bds8xProgressIndicatorTheme,
  );
}

ThemeData tbtThemeData({
  required String fontFamily,
}) {
  WowTextStyle.initTextTheme(tbtTextTheme);
  return ThemeData(
    fontFamily: fontFamily,
    appBarTheme: tbtAppBarTheme,
    textTheme: tbtTextTheme,
    textSelectionTheme: tbtTextSeletionTheme,
    backgroundColor: TBTColor.whiteFFFF,
    primaryColor: TBTColor.pink4667,
    indicatorColor: TBTColor.pink4667,
    scaffoldBackgroundColor: TBTColor.whiteFFFF,
    inputDecorationTheme: tbtInputDecorationTheme,
    iconTheme: tbtIconTheme,
    progressIndicatorTheme: tbtProgressIndicatorTheme,
  );
}
